@@ -1,7 +1,8 @@
 """Correlation plot functions."""
-
 from statsmodels.compat.pandas import deprecate_kwarg
 
+import calendar
+
 import numpy as np
 import pandas as pd
 
@@ -36,6 +37,7 @@ def _plot_corr(
     irregular,
     use_vlines,
     vlines_kwargs,
+    auto_ylims=False,
     **kwargs,
 ):
     if irregular:
@@ -56,6 +58,13 @@ def _plot_corr(
     ax.plot(lags, acf_x, **kwargs)
     ax.set_title(title)
 
+    ax.set_ylim(-1, 1)
+    if auto_ylims:
+        ax.set_ylim(
+            1.25 * np.minimum(min(acf_x), min(confint[:, 0] - acf_x)),
+            1.25 * np.maximum(max(acf_x), max(confint[:, 1] - acf_x)),
+        )
+
     if confint is not None:
         if lags[0] == 0:
             lags = lags[1:]
@@ -82,6 +91,8 @@ def plot_acf(
     missing="none",
     title="Autocorrelation",
     zero=True,
+    auto_ylims=False,
+    bartlett_confint=True,
     vlines_kwargs=None,
     **kwargs,
 ):
@@ -122,6 +133,27 @@ def plot_acf(
     zero : bool, optional
         Flag indicating whether to include the 0-lag autocorrelation.
         Default is True.
+    auto_ylims : bool, optional
+        If True, adjusts automatically the y-axis limits to ACF values.
+    bartlett_confint : bool, default True
+        Confidence intervals for ACF values are generally placed at 2
+        standard errors around r_k. The formula used for standard error
+        depends upon the situation. If the autocorrelations are being used
+        to test for randomness of residuals as part of the ARIMA routine,
+        the standard errors are determined assuming the residuals are white
+        noise. The approximate formula for any lag is that standard error
+        of each r_k = 1/sqrt(N). See section 9.4 of [1] for more details on
+        the 1/sqrt(N) result. For more elementary discussion, see section
+        5.3.2 in [2].
+        For the ACF of raw data, the standard error at a lag k is
+        found as if the right model was an MA(k-1). This allows the
+        possible interpretation that if all autocorrelations past a
+        certain lag are within the limits, the model might be an MA of
+        order defined by the last significant autocorrelation. In this
+        case, a moving average model is assumed for the data and the
+        standard errors for the confidence intervals should be
+        generated using Bartlett's formula. For more details on
+        Bartlett formula result, see section 7.2 in [1].
     vlines_kwargs : dict, optional
         Optional dictionary of keyword arguments that are passed to vlines.
     **kwargs : kwargs, optional
@@ -153,6 +185,12 @@ def plot_acf(
     vertical lines connecting each autocorrelation to the axis.  These options
     must be valid for a LineCollection object.
 
+    References
+    ----------
+    [1] Brockwell and Davis, 1987. Time Series Theory and Methods
+    [2] Brockwell and Davis, 2010. Introduction to Time Series and
+    Forecasting, 2nd edition.
+
     Examples
     --------
     >>> import pandas as pd
@@ -179,11 +217,12 @@ def plot_acf(
         nlags=nlags,
         alpha=alpha,
         fft=fft,
+        bartlett_confint=bartlett_confint,
         adjusted=adjusted,
         missing=missing,
     )
     if alpha is not None:
-        acf_x, confint = acf_x
+        acf_x, confint = acf_x[:2]
 
     _plot_corr(
         ax,
@@ -194,6 +233,7 @@ def plot_acf(
         irregular,
         use_vlines,
         vlines_kwargs,
+        auto_ylims=auto_ylims,
         **kwargs,
     )
 
@@ -205,7 +245,7 @@ def plot_pacf(
     ax=None,
     lags=None,
     alpha=0.05,
-    method="ywadjusted",
+    method="ywm",
     use_vlines=True,
     title="Partial Autocorrelation",
     zero=True,
@@ -231,15 +271,21 @@ def plot_pacf(
         returned. For instance if alpha=.05, 95 % confidence intervals are
         returned where the standard deviation is computed according to
         1/sqrt(len(x))
-    method : {'ywunbiased', 'ywmle', 'ols'}
+    method : str
         Specifies which method for the calculations to use:
 
-        - yw or ywunbiased : yule walker with bias correction in denominator
-          for acovf. Default.
-        - ywm or ywmle : yule walker without bias correction
-        - ols - regression of time series on lags of it and on constant
-        - ld or ldunbiased : Levinson-Durbin recursion with bias correction
-        - ldb or ldbiased : Levinson-Durbin recursion without bias correction
+        - "ywm" or "ywmle" : Yule-Walker without adjustment. Default.
+        - "yw" or "ywadjusted" : Yule-Walker with sample-size adjustment in
+          denominator for acovf. Default.
+        - "ols" : regression of time series on lags of it and on constant.
+        - "ols-inefficient" : regression of time series on lags using a single
+          common sample to estimate all pacf coefficients.
+        - "ols-adjusted" : regression of time series on lags with a bias
+          adjustment.
+        - "ld" or "ldadjusted" : Levinson-Durbin recursion with bias
+          correction.
+        - "ldb" or "ldbiased" : Levinson-Durbin recursion without bias
+          correction.
 
     use_vlines : bool, optional
         If True, vertical lines and markers are plotted.
@@ -291,7 +337,7 @@ def plot_pacf(
     >>> dta = sm.datasets.sunspots.load_pandas().data
     >>> dta.index = pd.Index(sm.tsa.datetools.dates_from_range('1700', '2008'))
     >>> del dta["YEAR"]
-    >>> sm.graphics.tsa.plot_acf(dta.values.squeeze(), lags=40)
+    >>> sm.graphics.tsa.plot_pacf(dta.values.squeeze(), lags=40, method="ywm")
     >>> plt.show()
 
     .. plot:: plots/graphics_tsa_plot_pacf.py
@@ -407,7 +453,8 @@ def month_plot(x, dates=None, ylabel=None, ax=None):
     else:
         x = pd.Series(x, index=pd.PeriodIndex(dates, freq="M"))
 
-    xticklabels = ["j", "f", "m", "a", "m", "j", "j", "a", "s", "o", "n", "d"]
+    # there's no zero month
+    xticklabels = list(calendar.month_abbr)[1:]
     return seasonal_plot(
         x.groupby(lambda y: y.month), xticklabels, ylabel=ylabel, ax=ax
     )
